@@ -17,6 +17,8 @@ from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     ArchitectureType,
+    ComputeTypeType,
+    DataSourceTypeType,
     DeploymentJobErrorCodeType,
     DeploymentStatusType,
     ExitBehaviorType,
@@ -36,11 +38,11 @@ from .literals import (
     WorldGenerationJobStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -282,6 +284,8 @@ ComputeResponseTypeDef = TypedDict(
     "ComputeResponseTypeDef",
     {
         "simulationUnitLimit": int,
+        "computeType": ComputeTypeType,
+        "gpuUnitLimit": int,
     },
     total=False,
 )
@@ -290,6 +294,8 @@ ComputeTypeDef = TypedDict(
     "ComputeTypeDef",
     {
         "simulationUnitLimit": int,
+        "computeType": ComputeTypeType,
+        "gpuUnitLimit": int,
     },
     total=False,
 )
@@ -731,14 +737,27 @@ CreateWorldTemplateResponseTypeDef = TypedDict(
     },
 )
 
-DataSourceConfigTypeDef = TypedDict(
-    "DataSourceConfigTypeDef",
+_RequiredDataSourceConfigTypeDef = TypedDict(
+    "_RequiredDataSourceConfigTypeDef",
     {
         "name": str,
         "s3Bucket": str,
         "s3Keys": Sequence[str],
     },
 )
+_OptionalDataSourceConfigTypeDef = TypedDict(
+    "_OptionalDataSourceConfigTypeDef",
+    {
+        "type": DataSourceTypeType,
+        "destination": str,
+    },
+    total=False,
+)
+
+
+class DataSourceConfigTypeDef(_RequiredDataSourceConfigTypeDef, _OptionalDataSourceConfigTypeDef):
+    pass
+
 
 DataSourceTypeDef = TypedDict(
     "DataSourceTypeDef",
@@ -746,6 +765,8 @@ DataSourceTypeDef = TypedDict(
         "name": str,
         "s3Bucket": str,
         "s3Keys": List["S3KeyOutputTypeDef"],
+        "type": DataSourceTypeType,
+        "destination": str,
     },
     total=False,
 )
@@ -1269,28 +1290,19 @@ GetWorldTemplateBodyResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredLaunchConfigTypeDef = TypedDict(
-    "_RequiredLaunchConfigTypeDef",
+LaunchConfigTypeDef = TypedDict(
+    "LaunchConfigTypeDef",
     {
         "packageName": str,
         "launchFile": str,
-    },
-)
-_OptionalLaunchConfigTypeDef = TypedDict(
-    "_OptionalLaunchConfigTypeDef",
-    {
         "environmentVariables": Dict[str, str],
         "portForwardingConfig": "PortForwardingConfigTypeDef",
         "streamUI": bool,
+        "command": List[str],
     },
     total=False,
 )
 
-
-class LaunchConfigTypeDef(_RequiredLaunchConfigTypeDef, _OptionalLaunchConfigTypeDef):
-    pass
-
-
 ListDeploymentJobsRequestRequestTypeDef = TypedDict(
     "ListDeploymentJobsRequestRequestTypeDef",
     {
@@ -1836,6 +1848,7 @@ SimulationJobSummaryTypeDef = TypedDict(
         "simulationApplicationNames": List[str],
         "robotApplicationNames": List[str],
         "dataSourceNames": List[str],
+        "computeType": ComputeTypeType,
     },
     total=False,
 )
